@@ -34,6 +34,9 @@ void pulseaudio_set_default(menu_info_item_t* mii)
 {
     pa_operation* o = NULL;
 
+    g_debug("[pulseaudio_action] set default %s to %s",
+            menu_info_type_name(mii->menu_info->type), mii->name);
+
     switch(mii->menu_info->type)
     {
         case MENU_SERVER:
@@ -133,7 +136,7 @@ void pulseaudio_move_success_cb(pa_context *c, int success, void *userdata)
 
 void pulseaudio_rename(menu_info_item_t* mii, const char* name)
 {
-    g_debug("rename %s '%s' to '%s'",
+    g_debug("[pulseaudio_action] rename %s '%s' to '%s'",
             menu_info_type_name(mii->menu_info->type), mii->desc, name);
 
     char *key = g_markup_printf_escaped("%s:%s", menu_info_type_name(mii->menu_info->type), mii->name);
@@ -157,7 +160,7 @@ void pulseaudio_rename_success_cb(pa_context *c, int success, void *userdata)
 
 void pulseaudio_volume(menu_info_item_t* mii, int inc)
 {
-    g_debug("pulseaudio_volume(%s, %i)", mii->name, inc);
+    g_debug("[pulseaudio_action] pulseaudio_volume(%s, %i)", mii->name, inc);
 
     /* increment/decrement in 2% steps */
     pa_cvolume* volume;
@@ -291,7 +294,7 @@ void pulseaudio_update_volume_notification(menu_info_item_t* mii)
 
 void pulseaudio_toggle_mute(menu_info_item_t* mii)
 {
-    g_debug("pulseaudio_toggle_mute(%s)", mii->name);
+    g_debug("[pulseaudio_action] pulseaudio_toggle_mute(%s)", mii->name);
 
     pa_operation* o = NULL;
 
