@@ -54,9 +54,9 @@ static icon_set_t ui_icon_names[MENU_COUNT];
 
 static GtkBuilder* builder;
 
-static void ui_load_icons(void);
+static void ui_load_icons(settings_t* settings);
 
-void ui_load()
+void ui_load(settings_t* settings)
 {
     builder = gtk_builder_new();
 
@@ -80,7 +80,7 @@ void ui_load()
     g_free(local_file);
     g_free(local_file_src);
 
-    ui_load_icons();
+    ui_load_icons(settings);
 
     if(!ret)
     {
@@ -150,23 +150,27 @@ GtkDialog* ui_errordialog(const gchar* title, const gchar* message)
     return GTK_DIALOG(dialog);
 }
 
-static const gchar* ui_find_icon_name(GtkIconTheme* theme, const gchar* name, const gchar* fallback)
+static const gchar* ui_find_icon_name(GtkIconTheme* theme, const gchar* name, const gchar* fallback, gboolean symbolic_icons)
 {
-    const gchar* s = g_strdup_printf("%s-symbolic", name);
-    if(gtk_icon_theme_has_icon(theme, s))
-        return s;
-    g_free(s);
+    if (symbolic_icons) {
+      gchar* s = g_strdup_printf("%s-symbolic", name);
+      if(gtk_icon_theme_has_icon(theme, s))
+          return s;
+      g_free(s);
+    }
+
     if(gtk_icon_theme_has_icon(theme, name))
         return g_strdup(name);
+
     return g_strdup(fallback);
 }
 
-static void ui_load_icons(void) {
+static void ui_load_icons(settings_t* settings) {
     GtkIconTheme* theme = gtk_icon_theme_get_default();
     for(menu_type_t mt = 0; mt < MENU_COUNT; mt++) {
         const gchar** preferred_names = (mt == MENU_SOURCE ? mic_icon_names : volume_icon_names);
         for(icon_idx_t i = 0; i < ICON_IDX_COUNT; i++) {
-            ui_icon_names[mt][i] = ui_find_icon_name(theme, preferred_names[i], volume_icon_names[i]);
+            ui_icon_names[mt][i] = ui_find_icon_name(theme, preferred_names[i], volume_icon_names[i], settings->symbolic_icons);
         }
     }
 }
